@@ -8,14 +8,16 @@ use Module::Pluggable::Object;
 use Catalyst::Request::REST;
 use Catalyst::Utils ();
 
-sub new {
-  my $class  = shift;
-  my $config = shift;
-  Catalyst::Request::REST->_insert_self_into( $config->{class} );
-  return $class->SUPER::new($config, @_);
-}
+our $VERSION = '0.82';
+$VERSION = eval $VERSION;
 
-__PACKAGE__->mk_accessors(qw(_serialize_plugins _loaded_plugins));
+after BUILDARGS => sub {
+    my $class  = shift;
+    my $config = shift;
+    Catalyst::Request::REST->_insert_self_into( $config->{class} );
+};
+
+has [qw(_serialize_plugins _loaded_plugins)] => ( is => 'rw' );
 
 sub _load_content_plugins {
     my $self = shift;
@@ -153,13 +155,11 @@ sub _serialize_bad_request {
     return undef;
 }
 
-1;
+__PACKAGE__->meta->make_immutable;
 
 =head1 NAME
 
-B<Catalyst::Action::SerializeBase>
-
-Base class for Catalyst::Action::Serialize and Catlayst::Action::Deserialize.
+Catalyst::Action::SerializeBase - Base class for Catalyst::Action::Serialize and Catlayst::Action::Deserialize.
 
 =head1 DESCRIPTION
 
